@@ -1,4 +1,4 @@
-# $Id: genotype.R,v 1.29 2004/05/25 19:40:02 warnesgr Exp $
+# $Id: genotype.R,v 1.30 2005/08/18 19:39:32 nj7w Exp $
 
 genotype  <- function(a1, a2=NULL, alleles=NULL, sep="/",
                       remove.spaces=TRUE,
@@ -481,7 +481,8 @@ heterozygote.genotype  <-  function(x,allele.name,...)
     if(missing(allele.name))
       retval  <- ifelse( is.na(a1) | is.na(a2), NA, !a1==a2 )
     else
-      retval  <- ( (a1==allele.name) + (a2==allele.name) ) == 1
+      retval  <- ((a1 %in% allele.name) | (a2 %in% allele.name)) &
+                 (a1 != a2)
     attr(retval,"locus")  <-  attr(x,"locus")
 #    class(retval)  <-  "homozygote"
     return(retval)
